@@ -297,12 +297,6 @@ def apply_to_vector(mat, vec):
     """
     if vec.size == 3:
         return np.dot(vec, mat)
-    elif vec.size == 4:
-        # convert to vec3 and undo w component
-        vec3 = vec[:-1] / vec[-1]
-        vec3 = np.dot(vec3, mat)
-        # convert back to vec4
-        return np.array([vec3[0], vec3[1], vec3[2], 1.0], dtype=vec.dtype)
     else:
         raise ValueError("Vector size unsupported")
 
